"""Crows Pairs group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

CROWS_PAIRS_TASKS = {
    "crows_pairs": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english_religion": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english_nationality": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english_race_color": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english_age": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english_gender": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english_disability": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english_sexual_orientation": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english_physical_appearance": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english_socioeconomic": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_english_autre": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french_religion": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french_nationality": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french_race_color": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french_age": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french_gender": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french_disability": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french_sexual_orientation": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french_physical_appearance": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french_socioeconomic": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
    "crows_pairs_french_autre": f"{BASE_IMPORT}crows_pairs:CrowsPairsExtractor",
}
