"""Evalita-Mp group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

# Note: evalita_mp extractor doesn't exist - use evalita_llm for the main tasks
EVALITA_MP_TASKS = {
    "evalita_LLM": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",  # Alias
    "evalita-mp": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_at": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_at_prompt-1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_at_prompt-2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_at_prompt-3": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_at_prompt-4": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_at_prompt-5": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_at_prompt-6": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_at_tasks": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_faq": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_faq_prompt-1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_faq_prompt-2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_faq_prompt-3": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_faq_prompt-4": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_faq_prompt-5": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_faq_prompt-6": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_faq_tasks": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_gen": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_hs": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_hs_prompt-1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_hs_prompt-2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_hs_prompt-3": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_hs_prompt-4": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_hs_prompt-5": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_hs_prompt-6": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_hs_tasks": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ls": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ls_prompt-1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ls_prompt-2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ls_tasks": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_mc": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner-v2_adg_p1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner-v2_adg_p2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner-v2_fic_p1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner-v2_fic_p2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner-v2_tasks_adg": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner-v2_tasks_fic": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner-v2_tasks_wn": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner-v2_wn_p1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner-v2_wn_p2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_adg_group": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_adg_p1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_adg_p2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_fic_group": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_fic_p1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_fic_p2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_group": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_tasks_adg": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_tasks_fic": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_tasks_wn": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_wn_group": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_wn_p1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_ner_wn_p2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_re": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_re_prompt-1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_re_prompt-2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_re_tasks": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sa": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sa_prompt-1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sa_prompt-2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sa_prompt-3": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sa_prompt-4": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sa_prompt-5": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sa_prompt-6": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sa_tasks": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sum_fp": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sum_fp-small_tasks": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_sum_fp_tasks": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_te": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_te_prompt-1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_te_prompt-2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_te_prompt-3": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_te_prompt-4": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_te_prompt-5": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_te_prompt-6": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_te_tasks": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_wic": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_wic_prompt-1": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_wic_prompt-2": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_wic_prompt-3": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_wic_prompt-4": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_wic_prompt-5": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_wic_prompt-6": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
    "evalita-mp_wic_tasks": f"{BASE_IMPORT}evalita_llm:EvalitaLlmExtractor",
}
