"""Hellaswag group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

HELLASWAG_TASKS = {
    "hellaswag": f"{BASE_IMPORT}hellaswag:HellaSwagExtractor",
    "hellaswag_it": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_sr": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_hr": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_ml": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_sk": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_pt": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_ta": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_de": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_ru": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_uk": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_nl": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_bn": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_hu": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_mr": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_hy": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_es": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_ar": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_sv": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_da": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_id": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_te": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_vi": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_eu": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_ro": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_hi": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_ca": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_gu": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_ne": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_fr": f"{BASE_IMPORT}okapi:OkapiExtractor",
    "hellaswag_kn": f"{BASE_IMPORT}okapi:OkapiExtractor",
}
