"""Global group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

GLOBAL_TASKS = {
    "global_mmlu": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",  # Parent task (handled by special case)
    "global_mmlu_ar": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ar_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ar_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ar_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ar_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ar_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ar_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_bn": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_bn_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_bn_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_bn_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_bn_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_bn_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_bn_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_de": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_de_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_de_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_de_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_de_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_de_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_de_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_en": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_en_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_en_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_en_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_en_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_en_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_en_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_es": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_es_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_es_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_es_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_es_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_es_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_es_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_fr": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_fr_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_fr_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_fr_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_fr_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_fr_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_fr_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_hi": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_hi_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_hi_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_hi_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_hi_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_hi_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_hi_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_id": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_id_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_id_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_id_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_id_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_id_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_id_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_it": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_it_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_it_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_it_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_it_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_it_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_it_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ja": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ja_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ja_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ja_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ja_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ja_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ja_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ko": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ko_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ko_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ko_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ko_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ko_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_ko_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_pt": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_pt_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_pt_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_pt_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_pt_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_pt_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_pt_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_sw": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_sw_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_sw_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_sw_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_sw_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_sw_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_sw_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_yo": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_yo_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_yo_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_yo_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_yo_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_yo_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_yo_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_zh": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_zh_business": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_zh_humanities": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_zh_medical": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_zh_other": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_zh_social_sciences": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_mmlu_zh_stem": f"{BASE_IMPORT}global_mmlu:GlobalMmluExtractor",
    "global_piqa": f"{BASE_IMPORT}global_piqa:GlobalPiqaExtractor",
}
