"""Egymmlu group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

EGYMMLU_TASKS = {
    "egymmlu": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_accounting": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_ar_mmlu": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_ar_mmlu_tasks": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_arabic_language": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_arabic_language_(general)": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_arabic_language_(grammar)": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_biology": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_civics": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_computer_science": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_driving_test": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_economics": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_general_knowledge": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_geography": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_global_facts": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_high_school_european_history": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_high_school_geography": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_high_school_government_and_politics": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_high_school_psychology": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_high_school_statistics": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_high_school_world_history": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_history": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_human_aging": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_humanities_tasks": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_international_law": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_islamic_studies": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_jurisprudence": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_language_tasks": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_law": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_logical_fallacies": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_management": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_management_ar": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_marketing": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_math": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_mmlu": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_mmlu_tasks": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_moral_disputes": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_moral_scenarios": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_natural_science": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_nutrition": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_other_tasks": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_philosophy": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_philosophy_ar": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_physics": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_political_science": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_professional_law": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_professional_psychology": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_public_relations": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_security_studies": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_social_science": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_social_sciences_tasks": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_sociology": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_stem_tasks": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
    "egymmlu_world_religions": f"{BASE_IMPORT}egymmlu:EgyMMLUExtractor",
}
