"""Arabicmmlu group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

ARABICMMLU_TASKS = {
    "arabicmmlu": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_accounting_university": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_arabic_language_general": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_arabic_language_grammar": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_arabic_language_high_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_arabic_language_middle_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_arabic_language_primary_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_biology_high_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_civics_high_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_civics_middle_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_computer_science_high_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_computer_science_middle_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_computer_science_primary_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_computer_science_university": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_driving_test": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_economics_high_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_economics_middle_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_economics_university": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_general_knowledge": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_general_knowledge_middle_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_general_knowledge_primary_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_geography_high_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_geography_middle_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_geography_primary_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_history_high_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_history_middle_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_history_primary_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_humanities": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_humanities_tasks": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_islamic_studies": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_islamic_studies_high_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_islamic_studies_middle_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_islamic_studies_primary_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_language": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_language_tasks": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_law_professional": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_management_university": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_math_primary_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_natural_science_middle_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_natural_science_primary_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_other": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_other_tasks": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_philosophy_high_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_physics_high_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_political_science_university": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_social_science": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_social_science_middle_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_social_science_primary_school": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_social_science_tasks": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_stem": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
    "arabicmmlu_stem_tasks": f"{BASE_IMPORT}arabicmmlu:ArabicmmluExtractor",
}
