"""CAA (Contrastive Activation Addition) steering method constants."""
from wisent.core.constant_definitions.for_experiments.by_method.simple._ostrze import *  # noqa: F401,F403

CAA_MIN_COSINE_SIMILARITY = 0.3
CAA_MAX_COSINE_SIMILARITY = 0.95
MIN_PAIRS_CAA = 10
